
---------------
Backend Drivers
---------------

.. automodule:: oslo_config.sources


Known Backend Drivers
---------------------

.. automodule:: oslo_config.sources._uri
.. automodule:: oslo_config.sources._environment
